@@ -27,6 +27,8 @@ try:
 except ImportError:
     DEVNULL = open(os.devnull, 'wb')
 
+from tmc.coloring import as_success, as_error
+
 
 def selected_course(func):
     """
@@ -71,19 +73,17 @@ def false_exit(func):
 @arg("-u", "--username", help="Username to be used.")
 @arg("-p", "--password", help="Password to be used.")
 @arg("-i", "--id", dest="tid", help="Course ID to be used.")
+@arg("-a", "--auto", action="store_true", help="Don't prompt for download path, use default instead")
 @false_exit
-def configure(server=None, username=None, password=None, tid=None):
+def configure(server=None, username=None, password=None, tid=None, auto=False):
     """
     Configure tmc.py to use your account.
     """
-    auto = False
     if not server and not username and not password and not tid:
         if Config.has():
             sure = input("Override old configuration [y/N]: ")
             if sure.upper() != "Y":
                 return False
-    else:
-        auto = True
     reset_db()
     if not server:
         while True:
@@ -130,7 +130,7 @@ def configure(server=None, username=None, password=None, tid=None):
             return False
         break
     if tid:
-        select(course=True, tid=tid, auto=True)
+        select(course=True, tid=tid, auto=auto)
     else:
         select(course=True)
 
@@ -192,12 +192,10 @@ def skip(course, num=1):
         pass
 
     if sel is None:
-        for i in course.exercises:
-            sel = i
-            break
+        sel = course.exercises.first()
     else:
         try:
-            sel = Exercise.byid(sel.id + num)
+            sel = Exercise.get(Exercise.id == sel.id + num)
         except peewee.DoesNotExist:
             print("There are no more exercises in this course.")
             return False
@@ -276,7 +274,7 @@ def select(course=False, tid=None, auto=False):
         ret = {}
         if not tid:
             ret = Menu.launch("Select an exercise",
-                              Course.get_selected(),
+                              Course.get_selected().exercises,
                               selected)
         else:
             ret["item"] = Exercise.byid(tid)
@@ -336,7 +334,7 @@ def list_all(course, single=None):
         return "●" if val else " "
 
     def bc(val):
-        return "\033[32m✔\033[0m" if val else "\033[31m✘\033[0m"
+        return as_success("✔") if val else as_error("✘")
 
     def format_line(exercise):
         return "{0} │ {1} │ {2} │ {3} │ {4}".format(exercise.tid,
@@ -349,7 +347,7 @@ def list_all(course, single=None):
         (len(str(course.exercises[0].tid)) - 1) * " "
     ))
     if single:
-        print(format(single))
+        print(format_line(single))
         return
     for exercise in course.exercises:
         # ToDo: use a pager
