@@ -1,5 +1,4 @@
 import os
-import sys
 import time
 import zipfile
 from io import BytesIO
@@ -8,6 +7,8 @@ from tmc import api
 from tmc.errors import NotDownloaded, TMCError, WrongExerciseType
 from tmc.ui.spinner import Spinner
 
+from tmc.coloring import successmsg, warningmsg, errormsg, infomsg
+
 
 def download_exercise(exercise, force=False, update_java=False):
     course = exercise.get_course()
@@ -59,6 +60,7 @@ def modify_java_target(exercise, old="1.6", new="1.7"):
 
 def submit_exercise(exercise, request_review=False, pastebin=False):
     outpath = exercise.path()
+    infomsg("Submitting from:", outpath)
     print("{} -> {}".format(exercise.menuname(), "TMC Server"))
     outpath = os.path.join(outpath, "src")
     if not os.path.isdir(outpath):
@@ -86,38 +88,63 @@ def submit_exercise(exercise, request_review=False, pastebin=False):
         zipfp.close()
         return api.send_zip(exercise.tid, tmpfile.getvalue(), params)
     resp = inner()
-    if "submission_url" in resp:
-        url = resp["submission_url"]
-        submission_id = int(url.split(".json")[0].split("submissions/")[1])
 
-        @Spinner.decorate("Results:", "Waiting for results.")
-        def inner():
-            while True:
-                data = api.get_submission(submission_id)
-                if data:
-                    return data
-                time.sleep(1)
-        data = inner()
-        success = True
-        if data["status"] == "fail":
-            sys.stderr.write("\033[31m")
-            for testcase in data["test_cases"]:
-                if not testcase["successful"]:
-                    sys.stderr.write("{}:\n  {}\n".format(testcase["name"],
-                                                          testcase["message"]))
-            sys.stderr.write("".join(["\033[33mFor better details run `tmc"
-                                      " test --id ", str(exercise.tid),
-                                      "`\033[0m\n"]))
-            success = False
-        elif data["status"] == "ok":
-            print("\033[32mPoints [" + ", ".join(data["points"]) + "]\033[0m")
-        if "paste_url" in data:
-            print("Pastebin: " + data["paste_url"])
-        if data.get("requests_review", False):
-            if data.get("reviewed", False):
-                print("This submission has been reviewed")
+    if "submission_url" not in resp:
+        return
+
+    url = resp["submission_url"]
+    submission_id = int(url.split(".json")[0].split("submissions/")[1])
+
+    @Spinner.decorate("Results:", "Waiting for results.")
+    def inner():
+        while True:
+            data = api.get_submission(submission_id)
+            if data:
+                return data
+            time.sleep(1)
+    data = inner()
+
+    success = True
+
+    status = data["status"]
+
+    if status == "fail":
+        warningmsg("Some tests failed:")
+        warningmsg("------------------")
+        for test in data["test_cases"]:
+            if test["successful"]:
+                successmsg("{name}: {message}\n".format(**test))
             else:
-                print("Requested a review")
-        print("URL: " + url.split(".json")[0])
-        if not success:
-            return False
+                errormsg("{name}:\n  {message}".format(**test))
+
+        helper = "For better details run 'tmc test --id {0}'\n"
+        warningmsg(helper.format(repr(exercise.tid)))
+        success = False
+
+    elif status == "ok":
+        successmsg("All tests successful!")
+        successmsg("---------------------")
+        points = ", ".join(data["points"])
+        successmsg("Points [{0}]".format(points))
+
+    elif status == "error":
+        warningmsg("Something went wrong :(")
+        warningmsg("-----------------------")
+        errormsg(data["error"])
+
+    else:
+        raise TMCError("Submission status unknown: {0}".format(status))
+
+    if "paste_url" in data:
+        infomsg("Pastebin URL: " + data["paste_url"])
+
+    if data.get("requests_review", False):
+        if data.get("reviewed", False):
+            infomsg("This submission has been reviewed")
+        else:
+            infomsg("Requested a review")
+
+    infomsg("Submission URL: " + url.split(".json")[0])
+
+    if not success:
+        return False
